@@ -3,6 +3,8 @@ from typing import BinaryIO, List
 
 import requests
 from pydantic import EmailStr, HttpUrl
+from requests.adapters import HTTPAdapter
+from urllib3.util.retry import Retry
 
 
 class MailGun:
@@ -25,7 +27,12 @@ class MailGun:
         cc: List[EmailStr] = [],
         bcc: List[EmailStr] = [],
     ):
-        return requests.post(
+        session = requests.Session()
+        retry = Retry(connect=3, backoff_factor=0.5)
+        adapter = HTTPAdapter(max_retries=retry)
+        session.mount("http://", adapter)
+        session.mount("https://", adapter)
+        return session.post(
             self.base_url + "/messages",
             auth=("api", self.api_key),
             files=[("attachment", attachment) for attachment in attachments],
@@ -51,7 +58,13 @@ class MailGun:
         cc: List[EmailStr] = [],
         bcc: List[EmailStr] = [],
     ):
-        return requests.post(
+
+        session = requests.Session()
+        retry = Retry(connect=3, backoff_factor=0.5)
+        adapter = HTTPAdapter(max_retries=retry)
+        session.mount("http://", adapter)
+        session.mount("https://", adapter)
+        return session.post(
             self.base_url + "/messages",
             auth=("api", self.api_key),
             files=[("attachment", attachment) for attachment in attachments],
